@@ -1,12 +1,9 @@
 import graphene
 
-from .types import (
-    schema_registry,
-    SchemaType,
-)
+from .types import SchemaType, schema_registry
 
 
-class Query(object):
+class Query:
     """Queries object."""
 
     gql_object_schema = graphene.Field(
@@ -25,8 +22,10 @@ class Query(object):
         required=True,
     )
 
+    @staticmethod
     def resolve_gql_object_schema(root, info, object_type, **kwargs):
         return schema_registry.get(object_type, None)
 
+    @staticmethod
     def resolve_gql_object_schema_all(root, info, **kwargs):
         return sorted(schema_registry.values(), key=lambda obj: obj["object_type"])
